summaryrefslogtreecommitdiff
path: root/build-scripts/fatbuild.sh
diff options
context:
space:
mode:
authorSam Lantinga <slouken@libsdl.org>2006-05-10 05:17:58 +0000
committerSam Lantinga <slouken@libsdl.org>2006-05-10 05:17:58 +0000
commitfea6ccebe3ff1b83215568de748926d41165c84a (patch)
tree34419fa50391e25f1c78cec1f32d0674c4b10c5e /build-scripts/fatbuild.sh
parent24dd26200fe4d61703df8050cb362015a10c2b07 (diff)
Fixed X11 support on Mac OS X Universal build
--HG-- extra : convert_revision : svn%3Ac70aab31-4412-0410-b14c-859654838e24/trunk%401758
Diffstat (limited to 'build-scripts/fatbuild.sh')
-rwxr-xr-xbuild-scripts/fatbuild.sh18
1 files changed, 14 insertions, 4 deletions
diff --git a/build-scripts/fatbuild.sh b/build-scripts/fatbuild.sh
index b7bf3073..3fd40cfb 100755
--- a/build-scripts/fatbuild.sh
+++ b/build-scripts/fatbuild.sh
@@ -10,7 +10,12 @@ NJOB=$NCPU
# Generic, cross-platform CFLAGS you always want go here.
CFLAGS="-O3 -g -pipe"
-# PowerPC compiler flags (10.2 runtime compatibility)
+# PowerPC configure flags (10.2 runtime compatibility)
+# We dynamically load X11, so using the system X11 headers is fine.
+CONFIG_PPC="--build=`uname -p`-apple-darwin --host=powerpc-apple-darwin \
+--x-includes=/usr/X11R6/include --x-libraries=/usr/X11R6/lib"
+
+# PowerPC compiler flags
CC_PPC="gcc-3.3 -arch ppc"
CXX_PPC="g++-3.3 -arch ppc"
CFLAGS_PPC=""
@@ -26,7 +31,12 @@ LFLAGS_PPC="-arch ppc \
-F/Developer/SDKs/MacOSX10.2.8.sdk/System/Library/Frameworks \
-Wl,-syslibroot,/Developer/SDKs/MacOSX10.2.8.sdk"
-# Intel compiler flags (10.4 runtime compatibility)
+# Intel configure flags (10.4 runtime compatibility)
+# We dynamically load X11, so using the system X11 headers is fine.
+CONFIG_X86="--build=`uname -p`-apple-darwin --host=i386-apple-darwin \
+--x-includes=/usr/X11R6/include --x-libraries=/usr/X11R6/lib"
+
+# Intel compiler flags
CC_X86="gcc-4.0 -arch i386"
CXX_X86="g++-4.0 -arch i386"
CFLAGS_X86="-mmacosx-version-min=10.4"
@@ -158,7 +168,7 @@ done
#
if test x$configure_ppc = xyes; then
(cd build/ppc && \
- sh ../../configure --build=`uname -p`-apple-darwin --host=powerpc-apple-darwin CC="$CC_PPC" CXX="$CXX_PPC" CFLAGS="$CFLAGS $CFLAGS_PPC" CPPFLAGS="$CPPFLAGS_PPC" LDFLAGS="$LFLAGS_PPC") || exit 2
+ sh ../../configure $CONFIG_PPC CC="$CC_PPC" CXX="$CXX_PPC" CFLAGS="$CFLAGS $CFLAGS_PPC" CPPFLAGS="$CPPFLAGS_PPC" LDFLAGS="$LFLAGS_PPC") || exit 2
fi
if test x$make_ppc = xyes; then
(cd build/ppc && ls include && make -j$NJOB) || exit 3
@@ -169,7 +179,7 @@ fi
#
if test x$configure_x86 = xyes; then
(cd build/x86 && \
- sh ../../configure --build=`uname -p`-apple-darwin --host=i386-apple-darwin CC="$CC_X86" CXX="$CXX_X86" CFLAGS="$CFLAGS $CFLAGS_X86" CPPFLAGS="$CPPFLAGS_X86" LDFLAGS="$LFLAGS_X86") || exit 2
+ sh ../../configure $CONFIG_X86 CC="$CC_X86" CXX="$CXX_X86" CFLAGS="$CFLAGS $CFLAGS_X86" CPPFLAGS="$CPPFLAGS_X86" LDFLAGS="$LFLAGS_X86") || exit 2
fi
if test x$make_x86 = xyes; then
(cd build/x86 && make -j$NJOB) || exit 3